==> RecordLinkage_0.3-5.zip: RecordLinkage/doc/EVT.R <==
###################################################
### chunk number 1: 
###################################################
#line 4 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
options(width=50)


###################################################
### chunk number 2: 
###################################################
#line 29 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
library(RecordLinkage)
library(xtable)


###################################################
### chunk number 3: 
###################################################
#line 34 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
data(RLdata500)
rpairs=compare.dedup(RLdata500,identity=identity.RLdata500,
  blockfld=list(1,3,5,6,7),strcmp=1:4)
rpairs=emWeights(rpairs)



###################################################
### chunk number 4: 
###################################################
#line 56 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
## Not run: getParetoThreshold(rpairs)


###################################################
### chunk number 5: 
###################################################
#line 61 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
plotMRL(rpairs)


###################################################
### chunk number 6: 
###################################################
#line 70 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
plotMRL(rpairs)
abline(v=c(1.2,12.8),col="red",lty="dashed")
l=mrl(rpairs$Wdata)
range=l$x>1.2 & l$x < 12.8
points(l$x[range], l$y[range],col="red",type="l")


###################################################
### chunk number 7: 
###################################################
#line 85 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/EVT.rnw"
threshold=getParetoThreshold(rpairs,interval=c(1.2,12.8))
result=emClassify(rpairs,threshold)
summary(result)

==> RecordLinkage_0.4-1.zip: RecordLinkage/doc/EVT.R <==
### R code from vignette source 'EVT.rnw'

###################################################
### code chunk number 1: EVT.rnw:3-4
###################################################
options(width=50)


###################################################
### code chunk number 2: EVT.rnw:28-30
###################################################
library(RecordLinkage)
library(xtable)


###################################################
### code chunk number 3: EVT.rnw:33-38
###################################################
data(RLdata500)
rpairs=compare.dedup(RLdata500,identity=identity.RLdata500,
  blockfld=list(1,3,5,6,7),strcmp=1:4)
rpairs=emWeights(rpairs)



###################################################
### code chunk number 4: EVT.rnw:55-56
###################################################
## Not run: getParetoThreshold(rpairs)


###################################################
### code chunk number 5: EVT.rnw:60-61
###################################################
plotMRL(rpairs)


###################################################
### code chunk number 6: EVT.rnw:69-74
###################################################
plotMRL(rpairs)
abline(v=c(1.2,12.8),col="red",lty="dashed")
l=mrl(rpairs$Wdata)
range=l$x>1.2 & l$x < 12.8
points(l$x[range], l$y[range],col="red",type="l")


###################################################
### code chunk number 7: EVT.rnw:84-87
###################################################
threshold=getParetoThreshold(rpairs,interval=c(1.2,12.8))
result=emClassify(rpairs,threshold)
summary(result)
